>From f816eb30ece7b7f28c17ab1eca43461073b0227c Mon Sep 17 00:00:00 2001
From: Roiy Shpaner <roiy@cs.umanitoba.ca>
Date: Tue, 15 Apr 2014 19:11:59 -0500
Subject: [PATCH 09/10] MED Support - Edit dialogs

---
 modules/gui/qt4/dialogs/delete_event.cpp | 271 ++++++++++++
 modules/gui/qt4/dialogs/delete_event.hpp |  62 +++
 modules/gui/qt4/dialogs/edit_event.cpp   | 691 +++++++++++++++++++++++++++++++
 modules/gui/qt4/dialogs/edit_event.hpp   |  98 +++++
 modules/gui/qt4/dialogs/save_med.cpp     | 127 ++++++
 modules/gui/qt4/dialogs/save_med.hpp     |  56 +++
 6 files changed, 1305 insertions(+)
 create mode 100644 modules/gui/qt4/dialogs/delete_event.cpp
 create mode 100644 modules/gui/qt4/dialogs/delete_event.hpp
 create mode 100644 modules/gui/qt4/dialogs/edit_event.cpp
 create mode 100644 modules/gui/qt4/dialogs/edit_event.hpp
 create mode 100644 modules/gui/qt4/dialogs/save_med.cpp
 create mode 100644 modules/gui/qt4/dialogs/save_med.hpp

diff --git a/modules/gui/qt4/dialogs/delete_event.cpp b/modules/gui/qt4/dialogs/delete_event.cpp
new file mode 100644
index 0000000..3c26ca6
--- /dev/null
+++ b/modules/gui/qt4/dialogs/delete_event.cpp
@@ -0,0 +1,271 @@
+/*****************************************************************************
+ * delete_event.cpp : delete_event display
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/delete_event.hpp"
+#include "input_manager.hpp"
+
+#include <QPushButton>
+#include <QTextEdit>
+#include <QLabel>
+#include <QDialogButtonBox>
+#include <QTimeEdit>
+#include <QDateTime>
+#include <QTime>
+
+
+DeleteEventDialog::DeleteEventDialog( intf_thread_t *_p_intf )
+               : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+    setWindowOpacity( var_InheritFloat( p_intf, "qt-opacity" ) );
+    setWindowTitle( qtr( "Delete Event" ) );
+    setWindowRole( "vlc-deleteEvent" );
+
+    eventIndex = -1;
+    eventLayer = -1;
+
+    mainLayout = NULL;
+}
+
+void DeleteEventDialog::deleteEvent()
+{
+    if ( THEMIM->getIM()->deleteMedSegmentAt( eventIndex ) != VLC_SUCCESS )  
+    {
+        msg_Err( p_intf, "Could not delete event with id=%d ", eventIndex);
+        return;
+    }
+
+    THEMIM->getIM()->eventsModified();
+
+    close();
+}
+
+void DeleteEventDialog::update()
+{
+    mainLayout = new QGridLayout( this );
+    mainLayout->setContentsMargins( 1, 1, 1, 1 );
+    mainLayout->setSpacing( 2 );
+    mainLayout->setSizeConstraint( QLayout::SetFixedSize );
+
+    seeksegment_t *p_event = NULL;
+    
+    if ( THEMIM->getIM()->getMedSegmentAt( &p_event, &eventIndex, INT64_C(-1), -1 ) != VLC_SUCCESS )  //Get active event in current time
+        return;
+
+
+    if ( !p_event )
+    {
+        QLabel* errorLabel = new QLabel( qtr( "No event was found in the current time point, please select an active event." ) );
+
+        mainLayout->addWidget( errorLabel, 0, 0, 1, 1 );
+
+        QDialogButtonBox *okButtonBox = new QDialogButtonBox( Qt::Horizontal, this );
+        okButtonBox->addButton( new QPushButton( qtr("&Ok"), this ), QDialogButtonBox::AcceptRole );
+
+        mainLayout->addWidget( okButtonBox, 1, 0, 1, 1, Qt::AlignCenter );
+
+        CONNECT( okButtonBox, accepted(), this, toggleVisible() );
+
+        return;
+    }
+
+
+    QLabel *deleteIntro = new QLabel( qtr( "Are you sure you want to delete this event?" ) );
+    deleteIntro->setAlignment( Qt::AlignCenter );
+    
+    mainLayout->addWidget( deleteIntro, 0, 0, 1, 2 );
+
+    QLabel *startTimeIntro = new QLabel( qtr( "Start Time:" ) );
+    startTimeIntro->setWordWrap( true );
+    startTimeIntro->setAlignment( Qt::AlignRight );
+
+    startTimeEdit = new QTimeEdit();
+    startTimeEdit->setDisplayFormat( "HH:mm:ss.zzz" );
+    startTimeEdit->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    startTimeEdit->setAlignment( Qt::AlignLeft );
+    startTimeEdit->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    startTimeEdit->setEnabled( false );
+
+    int64_t t = p_event->i_time_offset;
+
+    long time = t / 1000;
+    int ms = time % 1000;
+    
+    time /= 1000;
+    int seconds = time % 60;
+
+    time /= 60;
+    int minutes = time % 60;
+
+    time /= 60;
+    int hours = time;
+
+    QTime startTime;
+    startTime.setHMS( hours, minutes, seconds, ms );
+    startTimeEdit->setTime( startTime );
+
+    mainLayout->addWidget( startTimeIntro, 1, 0, 1, 1 );
+    mainLayout->addWidget( startTimeEdit, 1, 1, 1, 1 );
+
+    QLabel *endTimeIntro = new QLabel( qtr( "End Time:" ) );
+    endTimeIntro->setWordWrap( true );
+    endTimeIntro->setAlignment( Qt::AlignRight );
+
+    endTimeEdit = new QTimeEdit();
+    endTimeEdit->setDisplayFormat( "HH:mm:ss.zzz" );
+    endTimeEdit->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    endTimeEdit->setAlignment( Qt::AlignLeft );
+    endTimeEdit->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    endTimeEdit->setEnabled( false );
+
+
+    t = p_event->i_time_offset + p_event->i_time_duration;
+
+    time = t / 1000;
+    ms = time % 1000;
+    
+    time /= 1000;
+    seconds = time % 60;
+
+    time /= 60;
+    minutes = time % 60;
+
+    time /= 60;
+    hours = time;
+
+    QTime endTime;
+    endTime.setHMS( hours, minutes, seconds, ms );
+    endTimeEdit->setTime( endTime );
+
+    mainLayout->addWidget( endTimeIntro, 2, 0, 1, 1 );
+    mainLayout->addWidget( endTimeEdit, 2, 1, 1, 1 );
+
+
+    QLabel* layerIntro = new QLabel( qtr( N_("Events Layer: ") ) ); 
+    layerIntro->setContentsMargins( 3, 2, 0, 0 );
+    layerIntro->setAlignment( Qt::AlignRight );
+    mainLayout->addWidget( layerIntro, 3, 0, 1, 1 );
+
+    QLabel* layer = new QLabel( qtr( p_event->psz_layerName ) ); 
+    layer->setContentsMargins( 3, 2, 0, 0 );
+    layer->setAlignment( Qt::AlignLeft );
+    mainLayout->addWidget( layer, 3, 1, 1, 1 );
+
+    eventLayer = p_event->i_layer_id;
+
+    QLabel* idIntro = new QLabel( qtr( N_("Event Id: ") ) ); 
+    idIntro->setContentsMargins( 3, 2, 0, 0 );
+    idIntro->setAlignment( Qt::AlignRight );
+    mainLayout->addWidget( idIntro, 4, 0, 1, 1 );
+
+    QLabel* id = new QLabel( QString::number( p_event->i_eventNum ) ); 
+    id->setContentsMargins( 3, 2, 0, 0 );
+    id->setAlignment( Qt::AlignLeft );
+    mainLayout->addWidget( id, 4, 1, 1, 1 );
+
+    mainLayout->setVerticalSpacing(5);
+
+    QLabel* annotationIntro = new QLabel( qtr( N_("Annotation:") ) ); 
+    annotationIntro->setContentsMargins( 3, 2, 0, 0 );
+    mainLayout->addWidget( annotationIntro, 5, 0, 1, 7 );
+
+    annotation_text = new QTextEdit( qtr( p_event->psz_text ) );
+    annotation_text->setAcceptRichText( false );
+    annotation_text->setReadOnly( true );
+    mainLayout->addWidget( annotation_text, 6, 0, 1, 7 );
+
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox( Qt::Horizontal, this );
+
+    QPushButton *but = buttonBox->addButton( qtr("&Delete"), QDialogButtonBox::AcceptRole );
+    CONNECT( but, clicked(), this, deleteEvent() );
+
+    but = buttonBox->addButton( qtr("&Cancel"), QDialogButtonBox::RejectRole );
+    CONNECT( but, clicked(), this, toggleVisible() );
+
+    QHBoxLayout *buttonLayout = new QHBoxLayout( this );
+    buttonLayout->setSpacing( 0 );
+    buttonLayout->setContentsMargins( 0, 0, 0, 0 );
+    buttonLayout->addStretch( 1 );
+    buttonLayout->addWidget( buttonBox, 0 , Qt::AlignRight  );
+    mainLayout->addLayout( buttonLayout, 7, 0, 1, 2 );
+
+    CONNECT( THEMIM->getIM(), eventsChanged( bool ), this, close( ) );
+
+    QVLCTools::restoreWidgetPosition( p_intf, "DeleteEventDialog", this );
+
+    vlc_seeksegment_Delete( p_event );
+}
+
+void DeleteEventDialog::clear()
+{
+    if ( mainLayout != NULL )
+    {
+        QLayoutItem* item;
+        while ( ( item = mainLayout->takeAt( 0 ) ) != NULL )
+        {
+            delete item->widget();
+            delete item;
+        }
+        delete mainLayout;
+        mainLayout = NULL;
+    }
+
+    eventIndex = -1;
+    eventLayer = -1;
+}
+
+void DeleteEventDialog::close()
+{
+    QVLCTools::saveWidgetPosition( p_intf, "DeleteEventDialog", this );
+    QVLCDialog::close();
+    clear();
+}
+
+void DeleteEventDialog::reject()
+{
+    close();
+    QDialog::reject();
+}
+
+void DeleteEventDialog::toggleVisible()
+{
+    if( isVisible() ) 
+        close();
+    else
+    {
+        if ( !THEMIM->getIM()->hasInput() )
+            return;
+
+        update();
+        show();
+    }
+}
+
+DeleteEventDialog::~DeleteEventDialog()
+{
+    QVLCTools::saveWidgetPosition( p_intf, "DeleteEventDialog", this );
+    clear();
+}
diff --git a/modules/gui/qt4/dialogs/delete_event.hpp b/modules/gui/qt4/dialogs/delete_event.hpp
new file mode 100644
index 0000000..5ea2909
--- /dev/null
+++ b/modules/gui/qt4/dialogs/delete_event.hpp
@@ -0,0 +1,62 @@
+/*****************************************************************************
+ * delete_event.hpp : Delete Event
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef QVLC_DELETE_EVENT_DIALOG_H_
+#define QVLC_DELETE_EVENT_DIALOG_H_ 1
+
+#include "util/qvlcframe.hpp"
+
+#include "util/singleton.hpp"
+
+#include <QDateTime>
+
+class QTextEdit;
+class QTimeEdit;
+class QTime;
+
+class DeleteEventDialog : public QVLCDialog, public Singleton<DeleteEventDialog>
+{
+    Q_OBJECT
+private:
+    DeleteEventDialog( intf_thread_t * );
+    virtual ~DeleteEventDialog();
+    QGridLayout *mainLayout;
+    QTimeEdit *startTimeEdit;
+    QTimeEdit *endTimeEdit;
+    QTextEdit *annotation_text;
+    int eventIndex, eventLayer;
+
+private slots:
+    friend class    Singleton<DeleteEventDialog>;
+    void deleteEvent();
+    void clear();
+    void update();
+    void reject();
+
+public slots:
+    void toggleVisible();
+    void close();
+};
+
+#endif
+
diff --git a/modules/gui/qt4/dialogs/edit_event.cpp b/modules/gui/qt4/dialogs/edit_event.cpp
new file mode 100644
index 0000000..704481a
--- /dev/null
+++ b/modules/gui/qt4/dialogs/edit_event.cpp
@@ -0,0 +1,691 @@
+/*****************************************************************************
+ * edit_event.cpp : edit_event display
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/edit_event.hpp"
+#include "input_manager.hpp"
+#include "components/interface_widgets.hpp"
+#include "dialogs/new_layer.hpp"
+
+#include <QPushButton>
+#include <QTextEdit>
+#include <QLabel>
+#include <QDialogButtonBox>
+#include <QTimeEdit>
+#include <QDateTime>
+#include <QTime>
+#include <QComboBox>
+
+
+EditEventDialog::EditEventDialog( intf_thread_t *_p_intf )
+               : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+    setWindowOpacity( var_InheritFloat( p_intf, "qt-opacity" ) );
+    setWindowTitle( qtr( "Edit Event" ) );
+    setWindowRole( "vlc-editEvent" );
+
+    eventIndex = -1;
+    eventLayer = -1;
+    bIsEditingEnd = true;
+    bLayerAdded = false;
+    p_event = NULL;
+    bAutoJumpState = true;
+    mainLayout = NULL;
+
+    newLayerDialog = NewLayerDialog::getInstance( p_intf );
+    CONNECT( newLayerDialog, layerAdded( QString ), this, layerAdded( QString ) );
+}
+
+void EditEventDialog::editEvent()
+{
+    /* Add layer if needed */
+    if ( bLayerAdded && ( layersCombo->currentIndex() == layersCombo->count() - 1 ) )
+    {
+        char* newLayer = strdup ( (char*) qtu( layersCombo->currentText() ) );
+
+        if ( THEMIM->getIM()->addMedLayer( &newLayer ) != VLC_SUCCESS )
+        {
+            msg_Err( p_intf, "Could not add layer no.%d:  %s", layersCombo->currentIndex(), newLayer );
+            return;
+        }
+
+        bLayerAdded = false;
+    }
+
+    int64_t startTime = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( startTimeEdit->time() ) ) * 1000;
+
+    int64_t endTime = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( endTimeEdit->time() ) ) * 1000;
+
+    free( p_event->psz_layerName );
+    p_event->psz_layerName = strdup( (char*) qtu( layersCombo->currentText() ) );
+    p_event->i_layer_id = layersCombo->currentIndex();
+    p_event->i_time_offset = startTime;
+    p_event->i_time_duration = endTime - startTime;
+    free( p_event->psz_text );
+    char* newAnnotation = strdup( qtu( annotation_text->toPlainText() ) );
+    p_event->psz_text = newAnnotation;
+
+    if ( THEMIM->getIM()->deleteMedSegmentAt( eventIndex ) != VLC_SUCCESS )  
+    {
+        msg_Err( p_intf, "Could not edit event with id=%d ", eventIndex);
+        return;
+    }
+
+    /* Delete and re-add because the start point of the event may have changed which would require reinsertion */
+    if ( THEMIM->getIM()->addMedSegment( p_event ) != VLC_SUCCESS )  
+    {
+        msg_Err( p_intf, "Could not edit event with id=%d ", eventIndex);
+        return;
+    }
+
+    THEMIM->getIM()->eventsModified();
+
+    close();
+}
+
+void EditEventDialog::update()
+{
+    mainLayout = new QGridLayout( this );
+    mainLayout->setContentsMargins( 1, 1, 1, 1 );
+    mainLayout->setSpacing( 2 );
+    mainLayout->setSizeConstraint( QLayout::SetFixedSize );
+
+    if ( THEMIM->getIM()->getMedSegmentAt( &p_event, &eventIndex, INT64_C(-1), -1 ) != VLC_SUCCESS )  //Get active event in current time
+        return;
+
+    if ( !p_event )
+    {
+        QLabel* errorLabel = new QLabel( qtr( "No event was found in the current time point, please select an active event." ) );
+
+        mainLayout->addWidget( errorLabel, 0, 0, 1, 1 );
+
+        QDialogButtonBox *okButtonBox = new QDialogButtonBox( Qt::Horizontal, this );
+        okButtonBox->addButton( new QPushButton( qtr("&Ok"), this ), QDialogButtonBox::AcceptRole );
+
+        mainLayout->addWidget( okButtonBox, 1, 0, 1, 1, Qt::AlignCenter );
+
+        CONNECT( okButtonBox, accepted(), this, close() );
+
+        THEMIM->getIM()->setMedEditMode( disabled );
+
+        return;
+    }
+
+    /* Event Found */
+
+    /* Pause and set values to original event */
+    THEMIM->getIM()->getInputState( &playState );
+    if ( playState != PAUSE_S )
+        THEMIM->getIM()->setInputState( PAUSE_S );
+
+    THEMIM->getIM()->setInputTime( p_event->i_time_offset + p_event->i_time_duration ); 
+
+    /* layout */
+
+    QLabel *editIntro = new QLabel( qtr( "Are you sure you want to edit this event?" ) );
+    editIntro->setAlignment( Qt::AlignCenter );
+    
+    mainLayout->addWidget( editIntro, 0, 0, 1, 2 );
+
+    QFrame* timeFrame = new QFrame( this );
+    timeFrame->setFrameStyle( QFrame::Box );
+
+    timeEditLayout = new QGridLayout( timeFrame );
+
+    QLabel *orgStartTimeIntro = new QLabel( qtr( "Original Start Time:" ) );
+    orgStartTimeIntro->setWordWrap( false );
+    orgStartTimeIntro->setAlignment( Qt::AlignRight );
+
+    orgStartTime = new QTimeEdit();
+    orgStartTime->setDisplayFormat( "HH:mm:ss.zzz" );
+    orgStartTime->setAlignment( Qt::AlignLeft );
+    orgStartTime->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    orgStartTime->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    orgStartTime->setEnabled( false );
+
+
+    int64_t t = p_event->i_time_offset;
+
+    long time = t / 1000;
+    int ms = time % 1000;
+    
+    time /= 1000;
+    int seconds = time % 60;
+
+    time /= 60;
+    int minutes = time % 60;
+
+    time /= 60;
+    int hours = time;
+
+    QTime startTime;
+    startTime.setHMS( hours, minutes, seconds, ms );
+    orgStartTime->setTime( startTime );
+
+    QPushButton *resetStartButton = new QPushButton( QIcon(":/update"), "" );
+    resetStartButton->setToolTip( qtr("Reset Start Time") );
+    resetStartButton->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+    CONNECT( resetStartButton, clicked( ),
+                 this, resetStartTime( ) );
+
+    timeEditLayout->addWidget( orgStartTimeIntro, 0, 0, 1, 1 );
+    timeEditLayout->addWidget( orgStartTime, 0, 1, 1, 1 );
+    timeEditLayout->addWidget( resetStartButton, 0, 2, 1, 1, Qt::AlignLeft );
+
+    startTimeIntro = new QLabel( qtr( "Start Time:" ) );
+    startTimeIntro->setWordWrap( false );
+    startTimeIntro->setAlignment( Qt::AlignRight );
+
+    startTimeEdit = new QTimeEdit();
+    startTimeEdit->setDisplayFormat( "HH:mm:ss.zzz" );
+    startTimeEdit->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    startTimeEdit->setAlignment( Qt::AlignLeft );
+    startTimeEdit->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    startTimeEdit->setReadOnly( true );
+    startTimeEdit->setEnabled( false );
+    startTimeEdit->setTime( startTime );
+
+    focusStartButton = new QPushButton( QIcon(":/util/focus"), "" );
+    focusStartButton->setToolTip( qtr("Focus Start Time") );
+    focusStartButton->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+    CONNECT( focusStartButton, clicked( ),
+                 this, setEditModeStart( ) );
+
+    timeEditLayout->addWidget( startTimeIntro, 1, 0, 1, 1 );
+    timeEditLayout->addWidget( startTimeEdit, 1, 1, 1, 1 );
+    timeEditLayout->addWidget( focusStartButton, 1, 2, 1, 1, Qt::AlignLeft );
+
+    startTimeDisplayUpdate( startTime );
+
+    /* End Time */
+
+    QLabel *orgEndTimeIntro = new QLabel( qtr( "Original End Time:" ) );
+    orgEndTimeIntro->setWordWrap( true );
+    orgEndTimeIntro->setAlignment( Qt::AlignRight );
+
+    orgEndTime = new QTimeEdit();
+    orgEndTime->setDisplayFormat( "HH:mm:ss.zzz" );
+    orgEndTime->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    orgEndTime->setAlignment( Qt::AlignLeft );
+    orgEndTime->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    orgEndTime->setEnabled( false );
+
+    
+    t = p_event->i_time_offset + p_event->i_time_duration;
+
+    time = t / 1000;
+    ms = time % 1000;
+    
+    time /= 1000;
+    seconds = time % 60;
+
+    time /= 60;
+    minutes = time % 60;
+
+    time /= 60;
+    hours = time;
+
+    QTime endTime;
+    endTime.setHMS( hours, minutes, seconds, ms );
+    orgEndTime->setTime( endTime );
+
+    QPushButton *resetEndButton = new QPushButton( QIcon(":/update"), "" );
+    resetEndButton->setToolTip( qtr("Reset End Time") );
+    resetEndButton->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+    CONNECT( resetEndButton, clicked( ),
+                 this, resetEndTime( ) );
+
+    timeEditLayout->addWidget( orgEndTimeIntro, 2, 0, 1, 1 );
+    timeEditLayout->addWidget( orgEndTime, 2, 1, 1, 1 );
+    timeEditLayout->addWidget( resetEndButton, 2, 2, 1, 1, Qt::AlignLeft );
+
+    endTimeIntro = new QLabel( qtr( "End Time:" ) );
+    endTimeIntro->setWordWrap( false );
+    endTimeIntro->setAlignment( Qt::AlignRight );
+    endTimeIntro->setStyleSheet( "font: bold" );
+
+    endTimeEdit = new QTimeEdit();
+    endTimeEdit->setDisplayFormat( "HH:mm:ss.zzz" );
+    endTimeEdit->setButtonSymbols( QAbstractSpinBox::NoButtons );
+    endTimeEdit->setAlignment( Qt::AlignLeft );
+    endTimeEdit->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    endTimeEdit->setReadOnly( true );
+    endTimeEdit->setEnabled( true );
+
+    focusEndButton = new QPushButton( QIcon(":/util/focus"), "" );
+    focusEndButton->setToolTip( qtr("Focus End Time") );
+    focusEndButton->setEnabled( false );
+    focusEndButton->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+    CONNECT( focusEndButton, clicked( ),
+                 this, setEditModeEnd( ) );
+
+    timeEditLayout->addWidget( endTimeIntro, 3, 0, 1, 1 );
+    timeEditLayout->addWidget( endTimeEdit, 3, 1, 1, 1 );
+    timeEditLayout->addWidget( focusEndButton, 3, 2, 1, 1, Qt::AlignLeft  );
+
+    
+    QPushButton *setTimeButton = new QPushButton( QIcon(":/util/clock"), "" );
+    setTimeButton->setFixedSize( setTimeButton->sizeHint() );
+    setTimeButton->setToolTip( qtr("Set Time") );
+
+    CONNECT( setTimeButton, clicked( ),
+                 this, setTimeDialog( ) );
+
+    QFrame* line = new QFrame();
+    line->setFrameShape(QFrame::VLine);
+    line->setFrameShadow(QFrame::Sunken);
+
+    QLabel *jumpLabel = new QLabel( qtr( "Jump " ) );
+    jumpVal = new QSpinBox();
+    jumpVal->setRange( 1, 999 );
+    jumpVal->setValue( 5 );  /* default jump seconds value */
+    QLabel *jumpLabelEnd = new QLabel( qtr( " seconds " ) );
+
+    QPushButton *jumpBackButton = new QPushButton( QIcon(":/util/jump_back"), "" );
+    jumpBackButton->setToolTip( qtr("Jump back") );
+    CONNECT( jumpBackButton, clicked( ),
+                 this, jumpBack( ) );
+
+    QPushButton *jumpFwdButton = new QPushButton( QIcon(":/util/jump_forward"), "" );
+    jumpFwdButton->setToolTip( qtr("Jump forward") );
+    CONNECT( jumpFwdButton, clicked( ),
+                 this, jumpFwd( ) );
+
+    QHBoxLayout *jumpLayout = new QHBoxLayout( timeFrame );
+    jumpLayout->addWidget( setTimeButton );
+    jumpLayout->addWidget( line );
+    jumpLayout->addWidget( jumpLabel );
+    jumpLayout->addWidget( jumpVal );
+    jumpLayout->addWidget( jumpLabelEnd);
+    jumpLayout->addWidget( jumpBackButton );
+    jumpLayout->addWidget( jumpFwdButton );
+    jumpLayout->insertStretch(-1);
+    timeEditLayout->addLayout( jumpLayout, 4, 0, 1, 3 );
+
+    timeFrame->setLayout( timeEditLayout );
+    mainLayout->addWidget( timeFrame, 1, 0, 4, 3 );
+
+    mainLayout->setVerticalSpacing( 10 );
+
+    QLabel* layerIntro = new QLabel( qtr( N_("Events Layer: ") ) ); 
+    layerIntro->setContentsMargins( 3, 2, 0, 0 );
+    layerIntro->setAlignment( Qt::AlignRight );
+    mainLayout->addWidget( layerIntro, 5, 0, 1, 1 );
+
+    layersCombo = new QComboBox( this );
+    layersCombo->setObjectName(QString::fromUtf8("layersCombo"));
+    QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
+    sizePolicy.setHorizontalStretch(0);
+    sizePolicy.setVerticalStretch(0);
+    sizePolicy.setHeightForWidth(layersCombo->sizePolicy().hasHeightForWidth());
+    layersCombo->setSizePolicy(sizePolicy);
+
+    //Get options for layers
+    int* pi_layers;
+    char*** psz_layerNames;
+    if ( THEMIM->getIM()->getMedLayerNames( &psz_layerNames, &pi_layers ) != VLC_SUCCESS )
+        return;
+
+    for ( int i = 0; i < *pi_layers ; i++ )
+        layersCombo->addItem( qtr( (*psz_layerNames)[i] ) );
+
+    eventLayer = p_event->i_layer_id;
+    layersCombo->setCurrentIndex( eventLayer );
+
+    mainLayout->addWidget(layersCombo, 5, 1, 1, 1);
+
+    QPushButton *newLayerButton = new QPushButton( qtr( "&New" ) );
+    newLayerButton->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+    mainLayout->addWidget(newLayerButton, 5, 2 );
+
+    CONNECT( newLayerButton, clicked(), this, addLayer() );
+
+
+
+    QLabel* idIntro = new QLabel( qtr( N_("Event Id: ") ) ); 
+    idIntro->setContentsMargins( 3, 2, 0, 0 );
+    idIntro->setAlignment( Qt::AlignRight );
+    mainLayout->addWidget( idIntro, 6, 0, 1, 1 );
+
+    QLabel* id = new QLabel( QString::number( p_event->i_eventNum ) ); 
+    id->setContentsMargins( 3, 2, 0, 0 );
+    id->setAlignment( Qt::AlignLeft );
+    mainLayout->addWidget( id, 6, 1, 1, 1 );
+
+    mainLayout->setVerticalSpacing(5);
+
+    QLabel* annotationIntro = new QLabel( qtr( N_("Annotation:") ) ); 
+    annotationIntro->setContentsMargins( 3, 2, 0, 0 );
+    mainLayout->addWidget( annotationIntro, 7, 0, 1, 7 );
+
+    annotation_text = new QTextEdit();
+    annotation_text->setPlainText( qtr( p_event->psz_text ) );
+    annotation_text->setAcceptRichText( false );
+    mainLayout->addWidget( annotation_text, 8, 0, 1, 7 );
+    ////////////
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox( Qt::Horizontal, this );
+
+    QPushButton *but = buttonBox->addButton( qtr("&Edit"), QDialogButtonBox::AcceptRole );
+    CONNECT( but, clicked(), this, editEvent() );
+
+    but = buttonBox->addButton( qtr("&Cancel"), QDialogButtonBox::RejectRole );
+    CONNECT( but, clicked(), this, toggleVisible() );
+
+    QHBoxLayout *buttonLayout = new QHBoxLayout( this );
+    buttonLayout->setSpacing( 0 );
+    buttonLayout->setContentsMargins( 0, 0, 0, 0 );
+    buttonLayout->addStretch( 1 );
+    buttonLayout->addWidget( buttonBox, 0 , Qt::AlignRight  );
+    mainLayout->addLayout( buttonLayout, 9, 0, 1, 2 );
+
+    QVLCTools::restoreWidgetPosition( p_intf, "EditEventDialog", this );
+
+    CONNECT( THEMIM->getIM(), eventsChanged( bool ), this, close( ) );
+    CONNECT( THEMIM->getIM(), switchUiEdit( bool ),
+        this, setEditingMode( bool ) );
+    CONNECT( THEMIM->getIM(), positionUpdated( float, int64_t, int64_t ),
+        this, updateSegTimes( float, int64_t, int64_t ) );
+}
+
+void EditEventDialog::clear()
+{
+    disconnect( THEMIM->getIM(), SIGNAL( switchUiEdit( bool ) ),
+        this, SLOT( setEditingMode( bool ) ) );
+    disconnect( THEMIM->getIM(), SIGNAL( positionUpdated( float, int64_t, int64_t ) ),
+        this, SLOT( updateSegTimes( float, int64_t, int64_t ) ) );
+
+    if ( mainLayout != NULL )
+    {
+        QLayoutItem* item;
+        while ( ( item = mainLayout->takeAt( 0 ) ) != NULL )
+        {
+            delete item->widget();
+            delete item;
+        }
+        delete mainLayout;
+        mainLayout = NULL;
+    }
+
+    eventIndex = -1;
+    eventLayer = -1;
+    bIsEditingEnd = true;
+    vlc_seeksegment_Delete( p_event );
+    p_event = NULL;
+}
+
+void EditEventDialog::close()
+{
+    QVLCTools::saveWidgetPosition( p_intf, "EditEventDialog", this );
+    THEMIM->getIM()->setMedEditMode( disabled );
+    QVLCDialog::close();
+    clear();
+
+    tmpDisableAutoJump( false );
+
+    /* resume previous playing state */
+
+    if ( playState != PAUSE_S )
+        THEMIM->getIM()->setInputState( playState );
+}
+
+void EditEventDialog::reject()
+{
+    close();
+    QDialog::reject();
+}
+
+void EditEventDialog::tmpDisableAutoJump( bool bInEditMode )
+{
+    if ( bInEditMode )
+    {
+        THEMIM->getIM()->getAutoJump( &bAutoJumpState ); /* save autojump state */
+
+        THEMIM->getIM()->setAutoJump( false ); /* Set to off */
+
+        THEMIM->setAutoJumpButton( false );
+    }
+    else
+    {
+        THEMIM->getIM()->setAutoJump( bAutoJumpState ); /* restore autojump state */
+
+        THEMIM->setAutoJumpButton( true );
+    }
+}
+
+void EditEventDialog::toggleVisible()
+{
+    if( isVisible() ) 
+        close();
+    else
+    {
+        if ( !THEMIM->getIM()->hasInput() )
+            return;
+
+        tmpDisableAutoJump( true );
+
+        THEMIM->getIM()->setMedEditMode( segmentEnd );
+        update();
+        show();
+    }
+}
+
+void EditEventDialog::resetStartTime()
+{
+    if ( bIsEditingEnd )
+    {
+        startTimeEdit->setTime( orgStartTime->time() );
+        startTimeDisplayUpdate( orgStartTime->time() );
+    }
+    else
+    {
+        int64_t i_time = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( orgStartTime->time() ) ) * 1000;
+        THEMIM->getIM()->setInputTime( i_time );   
+    }
+}
+
+void EditEventDialog::resetEndTime()
+{
+    if ( !bIsEditingEnd )
+    {
+        endTimeEdit->setTime( orgEndTime->time() );
+        endTimeDisplayUpdate( orgEndTime->time() );
+    }
+    else
+    {
+        int64_t i_time = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( orgEndTime->time() ) ) * 1000;
+        THEMIM->getIM()->setInputTime( i_time );    
+    }
+}
+
+void EditEventDialog::updateSegTimes( float pos, int64_t t, int64_t length )
+{
+    VLC_UNUSED( length );
+
+    if ( pos == -1.f )
+        return;
+    
+    bool bFirstSet = false; 
+
+    long time = t / 1000;
+    int ms = time % 1000;
+    
+    time /= 1000;
+    int seconds = time % 60;
+
+    time /= 60;
+    int minutes = time % 60;
+
+    time /= 60;
+    int hours = time;
+
+    QTime newTime;
+    newTime.setHMS( hours, minutes, seconds, ms );
+        
+    if ( ( startTimeEdit->time() == QTime( 0,0,0 ) ) && ( endTimeEdit->time() == QTime( 0,0,0 ) ) )
+        bFirstSet = true;   /* On first use only, we need both times as the current marker */
+
+    /* update time and prevent circular updating by not triggeting the signal */
+    if ( bIsEditingEnd )
+    {
+        endTimeEdit->setTime( newTime );
+
+        if ( endTimeEdit->time() < startTimeEdit->time() )  //Avoid end before start
+        {
+            startTimeEdit->setTime( newTime );
+            startTimeDisplayUpdate( newTime );
+        }
+
+    }
+    if ( !bIsEditingEnd || bFirstSet )
+    {
+        startTimeEdit->setTime( newTime );
+
+        if ( endTimeEdit->time() < startTimeEdit->time() )  //Avoid end before start
+        {
+            endTimeEdit->setTime( newTime );
+            endTimeDisplayUpdate( newTime );
+        }
+    }
+}
+
+/* sends playback commands according to the time set in the startTimeEdit */
+void EditEventDialog::startTimeDisplayUpdate( QTime newTime )
+{
+    int64_t i_time = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( newTime ) ) * 1000;
+
+    THEMIM->getIM()->setEventTimes( i_time, INT64_C(-1) );
+}
+
+/* sends playback commands according to the time set in the endTimeEdit */
+void EditEventDialog::endTimeDisplayUpdate( QTime newTime )
+{
+    int64_t i_time = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( newTime ) ) * 1000;
+
+    THEMIM->getIM()->setEventTimes( INT64_C(-1), i_time );
+}
+
+
+/* jump x seconds back */
+void EditEventDialog::jumpBack( )
+{
+    jumpXSeconds( false );
+}
+
+/* jump x seconds forward */
+void EditEventDialog::jumpFwd( )
+{
+    jumpXSeconds( true );
+}
+
+/* jump x seconds */
+void EditEventDialog::jumpXSeconds( bool forwardJump )
+{
+    int64_t jumpLen = jumpVal->value() * 1000000;
+    int64_t jumpTime;
+
+    if ( bIsEditingEnd )
+        jumpTime = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( endTimeEdit->time() ) ) * 1000;
+    else
+        jumpTime = (int64_t) ( QTime( 0, 0, 0 ).msecsTo( startTimeEdit->time() ) ) * 1000;
+
+    if ( forwardJump )
+        jumpTime += jumpLen;
+    else
+        jumpTime -= jumpLen;
+    
+    if ( jumpTime < 0 )
+        jumpTime = 0;
+
+    THEMIM->getIM()->setInputTime( jumpTime );   
+}
+
+/* Switches between editing the start or the end of the segment, with the last point where the marker was when swapped */
+void EditEventDialog::setEditingMode( bool bIsSegEndEdit )
+{
+    bIsEditingEnd = bIsSegEndEdit;
+
+    if ( bIsEditingEnd )
+    {
+        startTimeIntro->setStyleSheet( "" );
+        startTimeEdit->setEnabled( false );
+        focusStartButton->setEnabled( true );
+        endTimeIntro->setStyleSheet( "font: bold" );
+        endTimeEdit->setEnabled( true );
+        focusEndButton->setEnabled( false );
+    }
+    else
+    {
+        endTimeIntro->setStyleSheet( "" );
+        endTimeEdit->setEnabled( false );
+        focusEndButton->setEnabled( true );
+        startTimeIntro->setStyleSheet( "font: bold" );
+        startTimeEdit->setEnabled( true );
+        focusStartButton->setEnabled( false );
+    }
+}
+
+void EditEventDialog::setEditModeStart( )
+{
+    setEditingMode( false );
+    THEMIM->getIM()->setMedEditMode( segmentStart );
+}
+    
+void EditEventDialog::setEditModeEnd( )
+{
+    setEditingMode( true );
+    THEMIM->getIM()->setMedEditMode( segmentEnd );
+}
+
+void EditEventDialog::setTimeDialog( )
+{
+    THEDP->gotoTimeDialog();
+}
+
+void EditEventDialog::addLayer()
+{
+    newLayerDialog->toggleVisible();
+}
+
+void EditEventDialog::layerAdded( QString newLayer )
+{
+    if ( !isVisible() )  //function only useful when window is active
+        return;
+
+    if ( !bLayerAdded )
+        layersCombo->addItem( newLayer );
+    else
+        layersCombo->setItemText( layersCombo->count() - 1, newLayer );     //Just update the layer name to be added
+
+    layersCombo->setCurrentIndex( layersCombo->count() - 1 );
+
+    bLayerAdded = true;
+}
+
+EditEventDialog::~EditEventDialog()
+{
+    QVLCTools::saveWidgetPosition( p_intf, "EditEventDialog", this );
+    clear();
+}
diff --git a/modules/gui/qt4/dialogs/edit_event.hpp b/modules/gui/qt4/dialogs/edit_event.hpp
new file mode 100644
index 0000000..2f181a1
--- /dev/null
+++ b/modules/gui/qt4/dialogs/edit_event.hpp
@@ -0,0 +1,98 @@
+/*****************************************************************************
+ * edit_event.hpp : Edit Event
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef QVLC_EDIT_EVENT_DIALOG_H_
+#define QVLC_EDIT_EVENT_DIALOG_H_ 1
+
+#include "util/qvlcframe.hpp"
+#include "util/singleton.hpp"
+#include "dialogs/new_layer.hpp"
+
+#include <QDateTime>
+
+class QTextEdit;
+class QTimeEdit;
+class QTime;
+class QLabel;
+class QComboBox;
+class QSpinBox;
+
+class EditEventDialog : public QVLCDialog, public Singleton<EditEventDialog>
+{
+    Q_OBJECT
+private:
+    EditEventDialog( intf_thread_t * );
+    virtual ~EditEventDialog();
+    void tmpDisableAutoJump( bool bInEditMode );
+    QGridLayout *mainLayout;
+    QGridLayout *timeEditLayout;
+    QComboBox *layersCombo;
+
+    QTimeEdit *orgStartTime;
+    QLabel *startTimeIntro;
+    QTimeEdit *startTimeEdit;
+    QPushButton *focusStartButton;
+
+    QTimeEdit *orgEndTime;
+    QLabel *endTimeIntro;
+    QTimeEdit *endTimeEdit;
+    QPushButton *focusEndButton;
+
+    QSpinBox *jumpVal;
+    QTextEdit *annotation_text;
+    seeksegment_t *p_event;
+    int eventIndex, eventLayer;
+    bool bIsEditingEnd;
+    NewLayerDialog *newLayerDialog;
+    bool bLayerAdded;
+    int playState;
+    bool bAutoJumpState;
+
+private slots:
+    friend class    Singleton<EditEventDialog>;
+    void jumpXSeconds( bool forwardJump );
+    void resetStartTime();
+    void resetEndTime();
+    void editEvent();
+    void clear();
+    void update();
+    void reject();
+
+public slots:
+    void setEditingMode( bool bIsSegEndEdit );
+    void updateSegTimes( float pos, int64_t t, int64_t length );
+    void startTimeDisplayUpdate( QTime newTime );
+    void endTimeDisplayUpdate( QTime newTime );
+    void setEditModeStart();
+    void setEditModeEnd();
+    void setTimeDialog();
+    void jumpBack();
+    void jumpFwd();
+    void addLayer();
+    void layerAdded( QString newLayer );
+    void toggleVisible();
+    void close();
+};
+
+#endif
+
diff --git a/modules/gui/qt4/dialogs/save_med.cpp b/modules/gui/qt4/dialogs/save_med.cpp
new file mode 100644
index 0000000..3ff330c
--- /dev/null
+++ b/modules/gui/qt4/dialogs/save_med.cpp
@@ -0,0 +1,127 @@
+/*****************************************************************************
+ * med_save.cpp: Save MED changes to file
+ *****************************************************************************
+ * Copyright © 2014 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/save_med.hpp"
+#include "input_manager.hpp"
+
+#include <QPushButton>
+#include <QDialogButtonBox>
+#include <QLabel>
+#include <QFileDialog>
+#include <QString>
+#include <QMessageBox>
+
+SaveMedDialog::SaveMedDialog( intf_thread_t *_p_intf ) :
+        QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+    setWindowTitle( qtr( "Save MED file" ) );
+    setWindowRole( "vlc-save-med" );
+
+    bRespReceived = false;
+
+    /* Buttons */
+    QPushButton *but;
+
+    QDialogButtonBox *box = new QDialogButtonBox( this );
+    but = box->addButton( qtr( "&Overwrite Existing" ), QDialogButtonBox::AcceptRole );
+    CONNECT( but, clicked(), this, overwrite() );
+	but->setToolTip( qtr( "Overwrite existing MED file" ) );
+
+    but = box->addButton( qtr( "&Save As..." ) , QDialogButtonBox::AcceptRole );
+    CONNECT( but, clicked(), this, save() );
+	but->setToolTip( qtr( "Keep existing MED file and save the new changes in a custom file" ) );
+	
+	but = box->addButton( qtr( "&Cancel" ) , QDialogButtonBox::RejectRole );
+    CONNECT( box, rejected(), this, cancel() );
+
+    QLabel *info = new QLabel( qtr( "Please select one of these save options:"),
+                               this );
+							   
+    /* Layout */
+    QVBoxLayout *vlay = new QVBoxLayout( this );
+
+    vlay->addWidget( info );
+    vlay->addWidget( box );
+
+    CONNECT( THEMIM->getIM(), medSaveResult( bool ), this, saveFileResult( bool ) );
+}
+
+void SaveMedDialog::overwrite()
+{
+    filename = "";
+    THEMIM->getIM()->saveEnhancementData( filename );
+
+    accept();
+}
+
+void SaveMedDialog::save()
+{
+    if( filename.isEmpty() )
+        filename = p_intf->p_sys->filepath;
+
+    filename = QFileDialog::getSaveFileName( NULL,
+                qtr( "Save MED file as..." ), filename, qtr( "MED file (*.med);;All (*.*)" ) );
+
+    if ( filename != NULL )
+        THEMIM->getIM()->saveEnhancementData( filename );
+
+    accept();
+}
+
+void SaveMedDialog::cancel()
+{
+    bRespReceived = true;
+    reject();
+}
+
+void SaveMedDialog::saveFileResult( bool result )
+{
+    bRespReceived = true;
+
+    QMessageBox msgBox;
+    QString msg;
+    if ( result )
+    {
+        msg = qtr( "<p align='center'>File " ) + filename + qtr( " saved.</p>" );
+    }
+    else
+        msg = qtr( "<p align='center'>Error! File " ) + filename + qtr( " not saved!</p>" );
+    msgBox.setText( msg );
+    msgBox.exec();
+}
+
+void SaveMedDialog::toggleVisible()
+{
+    if( isVisible() ) 
+        close();
+    else
+    {
+        if ( !THEMIM->getIM()->hasInput() )
+            return;
+        show();
+    }
+}
\ No newline at end of file
diff --git a/modules/gui/qt4/dialogs/save_med.hpp b/modules/gui/qt4/dialogs/save_med.hpp
new file mode 100644
index 0000000..67a66d7
--- /dev/null
+++ b/modules/gui/qt4/dialogs/save_med.hpp
@@ -0,0 +1,56 @@
+/*****************************************************************************
+ * save_med.hpp: Save MED changes to file
+ ****************************************************************************
+ * Copyright © 2014 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ ******************************************************************************/
+
+#ifndef QVLC_SAVE_MED_H_
+#define QVLC_SAVE_MED_H_ 1
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "util/qvlcframe.hpp"
+#include "util/singleton.hpp"
+
+class SaveMedDialog : public QVLCDialog, public Singleton<SaveMedDialog>
+{
+    Q_OBJECT
+
+public:
+    SaveMedDialog( intf_thread_t * );
+    virtual ~SaveMedDialog() {}
+
+private:
+    QString filename;
+    bool bRespReceived;
+
+private slots:
+    void overwrite();
+	void save();
+    void cancel();
+
+public slots:
+    void saveFileResult( bool );
+    void toggleVisible();
+};
+
+#endif
-- 
1.8.4.msysgit.0

